@@ -1,7 +1,9 @@
 #include "config.hpp"
+#include <array>
 #include <exception>
 #include <filesystem>
 #include <fstream>
+#include <iostream>
 #include <stdexcept>
 #include <string>
 #include <format>
@@ -499,16 +501,71 @@ CParseResult CConfig::parseVariable(const std::string& lhs, const std::string& r
     return result;
 }
 
-void CConfigImpl::parseComment(const std::string& comment) {
+SVariable* CConfigImpl::getVariable(const std::string& name) {
+    for (auto& v : envVariables) {
+        if (v.name == name)
+            return &v;
+    }
+
+    for (auto& v : variables) {
+        if (v.name == name)
+            return &v;
+    }
+
+    return nullptr;
+}
+
+std::optional<std::string> CConfigImpl::parseComment(const std::string& comment) {
     const auto COMMENT = trim(comment);
 
     if (!COMMENT.starts_with("hyprlang"))
-        return;
+        return std::nullopt;
 
-    CVarList args(COMMENT, 0, 's', true);
+    CConstVarList args(COMMENT, 0, 's', true);
 
-    if (args[1] == "noerror")
-        currentFlags.noError = args[2] == "true" || args[2] == "yes" || args[2] == "enable" || args[2] == "enabled" || args[2] == "set";
+    bool          negated         = false;
+    std::string   ifBlockVariable = "";
+
+    for (size_t i = 1; i < args.size(); ++i) {
+        if (args[i] == "noerror") {
+            if (negated)
+                currentFlags.noError = false;
+            else
+                currentFlags.noError = args[2] == "true" || args[2] == "yes" || args[2] == "enable" || args[2] == "enabled" || args[2] == "set" || args[2].empty();
+            break;
+        }
+
+        if (args[i] == "endif") {
+            if (!currentFlags.inAnIfBlock)
+                return "stray endif";
+            currentFlags.inAnIfBlock = false;
+            break;
+        }
+
+        if (args[i] == "if") {
+            ifBlockVariable = args[++i];
+            break;
+        }
+    }
+
+    if (!ifBlockVariable.empty()) {
+        if (currentFlags.inAnIfBlock)
+            return "nested if statements are not allowed";
+
+        if (ifBlockVariable.starts_with("!")) {
+            negated = true;
+            ifBlockVariable = ifBlockVariable.substr(1);
+        }
+
+        currentFlags.inAnIfBlock = true;
+
+        if (const auto VAR = getVariable(ifBlockVariable); VAR)
+            currentFlags.ifBlockFailed = negated ? VAR->truthy() : !VAR->truthy();
+        else
+            currentFlags.ifBlockFailed = !negated;
+    }
+
+    return std::nullopt;
 }
 
 std::expected<float, std::string> CConfigImpl::parseExpression(const std::string& s) {
@@ -569,10 +626,15 @@ CParseResult CConfig::parseLine(std::string line, bool dynamic) {
     auto commentPos = line.find('#');
 
     if (commentPos == 0) {
-        impl->parseComment(line.substr(1));
+        const auto COMMENT_RESULT = impl->parseComment(line.substr(1));
+        if (COMMENT_RESULT.has_value())
+            result.setError(*COMMENT_RESULT);
         return result;
     }
 
+    if (impl->currentFlags.inAnIfBlock && impl->currentFlags.ifBlockFailed)
+        return result;
+
     size_t lastHashPos = 0;
 
     while (commentPos != std::string::npos) {
@@ -642,11 +704,34 @@ CParseResult CConfig::parseLine(std::string line, bool dynamic) {
                 anyMatch = true;
             }
 
-            // parse expressions $(somevar + 2)
+            // parse expressions {{somevar + 2}}
             // We only support single expressions for now
-            while (RHS.contains("$(")) {
-                const auto BEGIN_EXPR = RHS.find("$(");
-                const auto END_EXPR   = RHS.find(')', BEGIN_EXPR + 2);
+            while (RHS.contains("{{")) {
+                auto firstUnescaped = RHS.find("{{");
+                // Keep searching until non-escaped expression start is found
+                while (firstUnescaped > 0) {
+                    // Special check to avoid undefined behaviour with std::basic_string::find_last_not_of
+                    auto amountSkipped = 0;
+                    for (int i = firstUnescaped - 1; i >= 0; i--) {
+                        if (RHS.at(i) != '\\')
+                            break;
+                        amountSkipped++;
+                    }
+                    // No escape chars, or even escape chars. means they escaped themselves.
+                    if (amountSkipped % 2 == 0)
+                        break;
+                    // Continue searching for next valid expression start.
+                    firstUnescaped = RHS.find("{{", firstUnescaped + 1);
+                    // Break if the next match is never found
+                    if (firstUnescaped == std::string::npos)
+                        break;
+                }
+                // Real match was never found.
+                if (firstUnescaped == std::string::npos)
+                    break;
+                const auto BEGIN_EXPR = firstUnescaped;
+                // "}}" doesnt need escaping. Would be invalid expression anyways.
+                const auto END_EXPR = RHS.find("}}", BEGIN_EXPR + 2);
                 if (END_EXPR != std::string::npos) {
                     // try to parse the expression
                     const auto RESULT = impl->parseExpression(RHS.substr(BEGIN_EXPR + 2, END_EXPR - BEGIN_EXPR - 2));
@@ -655,7 +740,7 @@ CParseResult CConfig::parseLine(std::string line, bool dynamic) {
                         return result;
                     }
 
-                    RHS = RHS.substr(0, BEGIN_EXPR) + std::format("{}", RESULT.value()) + RHS.substr(END_EXPR + 1);
+                    RHS = RHS.substr(0, BEGIN_EXPR) + std::format("{}", RESULT.value()) + RHS.substr(END_EXPR + 2);
                 } else
                     break;
             }
@@ -672,6 +757,27 @@ CParseResult CConfig::parseLine(std::string line, bool dynamic) {
         if (ISVARIABLE)
             return parseVariable(LHS, RHS, dynamic);
 
+        // Removing escape chars. -- in the future, maybe map all the chars that can be escaped.
+        // Right now only expression parsing has escapeable chars
+        const char                ESCAPE_CHAR = '\\';
+        const std::array<char, 2> ESCAPE_SET{'{', '}'};
+        for (size_t i = 0; RHS.length() != 0 && i < RHS.length() - 1; i++) {
+            if (RHS.at(i) != ESCAPE_CHAR)
+                continue;
+            //if escaping an escape, remove and skip the next char
+            if (RHS.at(i + 1) == ESCAPE_CHAR) {
+                RHS.erase(i, 1);
+                continue;
+            }
+            //checks if any of the chars were escapable.
+            for (const auto& ESCAPABLE_CHAR : ESCAPE_SET) {
+                if (RHS.at(i + 1) != ESCAPABLE_CHAR)
+                    continue;
+                RHS.erase(i--, 1);
+                break;
+            }
+        }
+
         bool found = false;
 
         for (auto& h : impl->handlers) {
